% Auto-generated chapter 21 for muslim
% Hadiths in this chapter: 158

\hadithdefcmd{muslim}{3801}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ، حَبَّانَ عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ ‏.‏\hadithno{3801}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade (two types of transactions) Mulamasa and Munabadha}}
\hadithdefcmd{muslim}{3802}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{3802}\hadithtrans{Abu Huraira (Allah be pleased with him) reported like this from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3803}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{3803}\hadithtrans{Abu Huraira reported from Allah's Messenger (ﷺ) a hadith like this through another chain cf transmitters}}
\hadithdefcmd{muslim}{3804}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلِ، بْنِ أَبِي صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ مِثْلَهُ ‏.‏\hadithno{3804}\hadithtrans{A hadith like this has been narrated on the authority of Abu Huraira (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{3805}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو، بْنُ دِينَارٍ عَنْ عَطَاءِ بْنِ مِينَاءَ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ نُهِيَ عَنْ بَيْعَتَيْنِ، الْمُلاَمَسَةِ وَالْمُنَابَذَةِ ‏.‏ أَمَّا الْمُلاَمَسَةُ فَأَنْ يَلْمِسَ كُلُّ وَاحِدٍ مِنْهُمَا ثَوْبَ صَاحِبِهِ بِغَيْرِ تَأَمُّلٍ وَالْمُنَابَذَةُ أَنْ يَنْبِذَ كُلُّ وَاحِدٍ مِنْهُمَا ثَوْبَهُ إِلَى الآخَرِ وَلَمْ يَنْظُرْ وَاحِدٌ مِنْهُمَا إِلَى ثَوْبِ صَاحِبِهِ‏.‏\hadithno{3805}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Two types of trarisactions have been forbidden (by the Holy Prophet), al-Mlulamasa and al-Munabadha. As far as Mulamasa transaction is concerned, it is that every one of them (the parties entering into transaction) should touch the garment of the other without careful consideration, and al-Munabadha is that every one of them should throw his cloth to the other and one of them should not see the cloth of his friend}}
\hadithdefcmd{muslim}{3806}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لِحَرْمَلَةَ - قَالاَ أَخْبَرَنَا ابْنُ، وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَامِرُ بْنُ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّ أَبَا سَعِيدٍ، الْخُدْرِيَّ قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعَتَيْنِ وَلِبْسَتَيْنِ نَهَى عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ فِي الْبَيْعِ ‏.‏ وَالْمُلاَمَسَةُ لَمْسُ الرَّجُلِ ثَوْبَ الآخَرِ بِيَدِهِ بِاللَّيْلِ أَوْ بِالنَّهَارِ وَلاَ يَقْلِبُهُ إِلاَّ بِذَلِكَ وَالْمُنَابَذَةُ أَنْ يَنْبِذَ الرَّجُلُ إِلَى الرَّجُلِ بِثَوْبِهِ وَيَنْبِذَ الآخَرُ إِلَيْهِ ثَوْبَهُ وَيَكُونُ ذَلِكَ بَيْعَهُمَا مِنْ غَيْرِ نَظَرٍ وَلاَ تَرَاضٍ ‏.‏\hadithno{3806}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:Allah's Messenger (ﷺ) forbade us (from), two types of business transactions and two ways of dressing. He forbade Mulamasa and Munabadha in transactions. Mulamasa means the touching of another's garment with his hand, whether at night or by day, without turning it over except this much. Munabadha means that a man throws his garment to another and the other throws his garment, and thus confirming their contract without the inspection of mutual agreement}}
\hadithdefcmd{muslim}{3807}{وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{3807}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab through the same chain of transmitters}}
\hadithdefcmd{muslim}{3808}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَيَحْيَى بْنُ سَعِيدٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْحَصَاةِ وَعَنْ بَيْعِ الْغَرَرِ ‏.‏\hadithno{3808}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade a transaction determined by throwing stones, and the type which involves some uncertainty}}
\hadithdefcmd{muslim}{3809}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ ‏.‏\hadithno{3809}\hadithtrans{Abdullah (b. 'Umar) (Allah be pleased with him) said that Allah's Messenger (ﷺ) forbade the transaction called habal al-habala}}
\hadithdefcmd{muslim}{3810}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ أَهْلُ الْجَاهِلِيَّةِ يَتَبَايَعُونَ لَحْمَ الْجَزُورِ إِلَى حَبَلِ الْحَبَلَةِ ‏.‏ وَحَبَلُ الْحَبَلَةِ أَنْ تُنْتَجَ النَّاقَةُ ثُمَّ تَحْمِلَ الَّتِي نُتِجَتْ فَنَهَاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ ‏.‏\hadithno{3810}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that the people of pre-Islamic days used to sell the meat of the slaughtered camel up to habal al-habala. And habal al-habala implies that a she-camel should give birth and then the (born one should grow young) and become pregnant. Allah's Messenger (ﷺ) forbade them that (this transaction)}}
\hadithdefcmd{muslim}{3811}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ ‏"‏ ‏.‏\hadithno{3811}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as having said this:One amongst you should not enter into a transaction when another is bargaining}}
\hadithdefcmd{muslim}{3812}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِعِ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَخْطُبْ عَلَى خِطْبَةِ أَخِيهِ إِلاَّ أَنْ يَأْذَنَ لَهُ ‏"‏ ‏.‏\hadithno{3812}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:A person should not enter into a transaction when his brother is already making a transaction and he should not make a proposal of marriage when his brother has already made a proposal except when he gives permission}}
\hadithdefcmd{muslim}{3813}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَسُمِ الْمُسْلِمُ عَلَى سَوْمِ أَخِيهِ ‏"‏ ‏.‏\hadithno{3813}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A Muslim should not purchase (in opposition) to his brother}}
\hadithdefcmd{muslim}{3814}{وَحَدَّثَنِيهِ أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الْعَلاَءِ، وَسُهَيْلٍ عَنْ أَبِيهِمَا، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح. وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح. وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَسْتَامَ الرَّجُلُ عَلَى سَوْمِ أَخِيهِ ‏.‏ وَفِي رِوَايَةِ الدَّوْرَقِيِّ عَلَى سِيمَةِ أَخِيهِ ‏.‏\hadithno{3814}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters but with a slight change of words}}
\hadithdefcmd{muslim}{3815}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُتَلَقَّى الرُّكْبَانُ لِبَيْعٍ وَلاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَلاَ تَنَاجَشُوا وَلاَ يَبِعْ حَاضِرٌ لِبَادٍ وَلاَ تُصَرُّوا الإِبِلَ وَالْغَنَمَ فَمَنِ ابْتَاعَهَا بَعْدَ ذَلِكَ فَهُوَ بِخَيْرِ النَّظَرَيْنِ بَعْدَ أَنْ يَحْلُبَهَا فَإِنْ رَضِيَهَا أَمْسَكَهَا وَإِنْ سَخِطَهَا رَدَّهَا وَصَاعًا مِنْ تَمْرٍ ‏"‏ ‏.‏\hadithno{3815}\hadithtrans{Abu Huraira reported Allah's Messenger (may peace'be upon him) as saying:Do not go out to meet riders to enter into transaction with them; none of you must buy in opposition to another, nor must you bid against one another; a townsman must not sell for a man from the desert, and do not tie up udders of carnels and sheep, and he who buys them after that has been done has two courses open to him: after he has milked them he may keep them if he is pleased with them, or he may return them along with a sit of dates if he is displeased with them}}
\hadithdefcmd{muslim}{3816}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ التَّلَقِّي لِلرُّكْبَانِ وَأَنْ يَبِيعَ حَاضِرٌ لِبَادٍ وَأَنْ تَسْأَلَ الْمَرْأَةُ طَلاَقَ أُخْتِهَا وَعَنِ النَّجْشِ وَالتَّصْرِيَةِ وَأَنْ يَسْتَامَ الرَّجُلُ عَلَى سَوْمِ أَخِيهِ ‏.‏\hadithno{3816}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade the (people) meeting the caravan (for entering into business transaction with them), and the selling of goods by a townsman on behalf of a man of the desert, and seeking by a woman the divorce of her sister (from her husband), and outbidding (against one another), and tying up the udders (of animals), and buying of (things) in opposition to one's brother}}
\hadithdefcmd{muslim}{3817}{وَحَدَّثَنِيهِ أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا غُنْدَرٌ، ح وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا وَهْبُ، بْنُ جَرِيرٍ ح وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا أَبِي قَالُوا، جَمِيعًا حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏ فِي حَدِيثِ غُنْدَرٍ وَوَهْبٍ نُهِيَ ‏.‏ وَفِي حَدِيثِ عَبْدِ الصَّمَدِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى ‏.‏ بِمِثْلِ حَدِيثِ مُعَاذٍ عَنْ شُعْبَةَ ‏.‏\hadithno{3817}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{3818}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ النَّجْشِ ‏.‏\hadithno{3818}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) forbade the outbidding (against another)}}
\hadithdefcmd{muslim}{3819}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى يَعْنِي ابْنَ سَعِيدٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي كُلُّهُمْ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُتَلَقَّى السِّلَعُ حَتَّى تَبْلُغَ الأَسْوَاقَ ‏.‏ وَهَذَا لَفْظُ ابْنِ نُمَيْرٍ ‏.‏ وَقَالَ الآخَرَانِ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ التَّلَقِّي ‏.‏\hadithno{3819}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:Do not go out to meet merchandise in the way, (wait) until it is brought into the market. This hadith has been reported on the authority of Ibn Numair but with a slight change of words}}
\hadithdefcmd{muslim}{3820}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، جَمِيعًا عَنِ ابْنِ مَهْدِيٍّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ عَنْ عُبَيْدِ اللَّهِ ‏.‏\hadithno{3820}\hadithtrans{This hadith has been reported on the authority of 'Ubaidullah}}
\hadithdefcmd{muslim}{3821}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُبَارَكٍ، عَنِ التَّيْمِيِّ، عَنْ أَبِي، عُثْمَانَ عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ تَلَقِّي الْبُيُوعِ ‏.‏\hadithno{3821}\hadithtrans{Abdullah (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:Do not meet the traders (in the way)}}
\hadithdefcmd{muslim}{3822}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَلَقَّى الْجَلَبُ ‏\hadithno{3822}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (may peace he upon him) as saying:Do not meet the merchandise (in the way)}}
\hadithdefcmd{muslim}{3823}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا هِشَامُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي هِشَامٌ، الْقُرْدُوسِيُّ عَنِ ابْنِ سِيرِينَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَلَقَّوُا الْجَلَبَ ‏.‏ فَمَنْ تَلَقَّاهُ فَاشْتَرَى مِنْهُ فَإِذَا أَتَى سَيِّدُهُ السُّوقَ فَهُوَ بِالْخِيَارِ‏"‏ ‏.‏\hadithno{3823}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Do not meet the merchant in the way and enter into business transaction with him, and whoever meets him and buys from him (and in case it is done, see) that when the owner of (merchandise) comes into the market (and finds that he has been paid less price) he has the option (to declare the transaction null and void)}}
\hadithdefcmd{muslim}{3824}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِعْ حَاضِرٌ لِبَادٍ ‏"‏ ‏.‏ وَقَالَ زُهَيْرٌ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏\hadithno{3824}\hadithtrans{Abu Huraira (Allah be pleased with him) reported it directly from Allah's Apostle (ﷺ):The townsman'should not sell for a man from the desert (with a view to taking advantage of his ignorance of the market conditions of the city). And Zuhair reported from the Prophet (ﷺ) that he forbade the townsman to sell on behalf of the man from the desert}}
\hadithdefcmd{muslim}{3825}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُتَلَقَّى الرُّكْبَانُ وَأَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏.‏ قَالَ فَقُلْتُ لاِبْنِ عَبَّاسٍ مَا قَوْلُهُ حَاضِرٌ لِبَادٍ قَالَ لاَ يَكُنْ لَهُ سِمْسَارًا\hadithno{3825}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:The riders (carrying merchandise) should not be met in the way, and townsman should not sell for a man of the desert. The narrator reported. I said to Ibn 'Abbas: What do these words really imply-" The townsman for the man of the desert"? He said: That he should work as a broker on his behalf}}
\hadithdefcmd{muslim}{3826}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، ح. وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَبِعْ حَاضِرٌ لِبَادٍ دَعُوا النَّاسَ يَرْزُقِ اللَّهُ بَعْضَهُمْ مِنْ بَعْضٍ‏"‏ ‏.‏ غَيْرَ أَنَّ فِي رِوَايَةِ يَحْيَى ‏"‏ يُرْزَقُ ‏"‏ ‏.‏\hadithno{3826}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The townsman should not sell for a man from the desert, leave the people alone, Allah will give them provision from one another. Yahya reported it with a slight change of words}}
\hadithdefcmd{muslim}{3827}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{3827}\hadithtrans{Jabir (Allah be pleased with him) reported a similar hadith from Allah's Apostle (ﷺ) through another chain of transmitters}}
\hadithdefcmd{muslim}{3828}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ يُونُسَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسِ، بْنِ مَالِكٍ قَالَ نُهِينَا أَنْ يَبِيعَ، حَاضِرٌ لِبَادٍ ‏.‏ وَإِنْ كَانَ أَخَاهُ أَوْ أَبَاهُ ‏.‏\hadithno{3828}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported:We were forbidden that a townsman should sell for a man of the desert, even if he is his brother or father}}
\hadithdefcmd{muslim}{3829}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ،ح ‏.‏ وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذٌ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ نُهِينَا عَنْ أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏.‏\hadithno{3829}\hadithtrans{Anas b. Malik (Allah be pleased with him) said:We were forbidden that a townsman should sell for a man of the desert}}
\hadithdefcmd{muslim}{3830}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ مُوسَى بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اشْتَرَى شَاةً مُصَرَّاةً فَلْيَنْقَلِبْ بِهَا فَلْيَحْلُبْهَا فَإِنْ رَضِيَ حِلاَبَهَا أَمْسَكَهَا وَإِلاَّ رَدَّهَا وَمَعَهَا صَاعٌ مِنْ تَمْرٍ ‏"‏ ‏.‏\hadithno{3830}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (may peace be'upon him) as saying:He who bought a goat having its udder tied up should go back with it, milk it, and, if he is satisfied with its milk, he should retair it, otherwise he should return it along with a sa' of dates}}
\hadithdefcmd{muslim}{3831}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ شَاةً مُصَرَّاةً فَهُوَ فِيهَا بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ إِنْ شَاءَ أَمْسَكَهَا وَإِنْ شَاءَ رَدَّهَا وَرَدَّ مَعَهَا صَاعًا مِنْ تَمْرٍ ‏"‏ ‏.‏\hadithno{3831}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who buys a goat with its udder tied up has the option to retain the goat if he so desires or return it within three days, and in case he returns it he should do so along with a sa' of dates}}
\hadithdefcmd{muslim}{3832}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ بْنِ أَبِي رَوَّادٍ، حَدَّثَنَا أَبُو عَامِرٍ، - يَعْنِي الْعَقَدِيَّ - حَدَّثَنَا قُرَّةُ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اشْتَرَى شَاةً مُصَرَّاةً فَهُوَ بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ فَإِنْ رَدَّهَا رَدَّ مَعَهَا صَاعًا مِنْ طَعَامٍ لاَ سَمْرَاءَ ‏"‏‏.‏\hadithno{3832}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:lie who buys a goat having its udder tied up has the option to return it within three days. If he returns it he should pay a sa' of dates. Wheat is not essential}}
\hadithdefcmd{muslim}{3833}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اشْتَرَى شَاةً مُصَرَّاةً فَهُوَ بِخَيْرِ النَّظَرَيْنِ إِنْ شَاءَ أَمْسَكَهَا وَإِنْ شَاءَ رَدَّهَا وَصَاعًا مِنْ تَمْرٍ لاَ سَمْرَاءَ ‏"‏ ‏.‏\hadithno{3833}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who buys a goat having its udder tied up has two courses left for him. He may retain it, and if he desires may return it along with a sa' of dates and not wheat}}
\hadithdefcmd{muslim}{3834}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ مَنِ اشْتَرَى مِنَ الْغَنَمِ فَهُوَ بِالْخِيَارِ ‏"‏ ‏.‏\hadithno{3834}\hadithtrans{Ayyub narrated with the same chain of transmitters but with this change of words:" He who buys a goat has the option}}
\hadithdefcmd{muslim}{3835}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَا أَحَدُكُمُ اشْتَرَى لِقْحَةً مُصَرَّاةً أَوْ شَاةً مُصَرَّاةً فَهُوَ بِخَيْرِ النَّظَرَيْنِ بَعْدَ أَنْ يَحْلُبَهَا إِمَّا هِيَ وَإِلاَّ فَلْيَرُدَّهَا وَصَاعًا مِنْ تَمْرٍ ‏"‏ ‏.‏\hadithno{3835}\hadithtrans{Hammam b. Munabbih said:Out of the ahadith which Abu Huraira (Allah be pleased with him) reported to us from Allah's Messenger (ﷺ) one is this that Allah's Messenger (ﷺ) said: If one among you buys a she-camel having its udder tied up he has the two options for him after milking it either (to retain it) or return it with a sa' of dates}}
\hadithdefcmd{muslim}{3837}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَأَحْسِبُ كُلَّ شَىْءٍ مِثْلَهُ ‏.‏\hadithno{3837}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who buys foodgrain should not sell it until he has taken possession of it}}
\hadithdefcmd{muslim}{3838}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَأَحْمَدُ بْنُ عَبْدَةَ، قَالاَ حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ، أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، - وَهُوَ الثَّوْرِيُّ - كِلاَهُمَا عَنْ عَمْرِو، بْنِ دِينَارٍ بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3838}\hadithtrans{A hadith like this has been narrated through the same chain of transmitters}}
\hadithdefcmd{muslim}{3839}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَقْبِضَهُ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَأَحْسِبُ كُلَّ شَىْءٍ بِمَنْزِلَةِ الطَّعَامِ ‏.‏\hadithno{3839}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who buys food-rain should not sell it until he has taken possession of it. Ibn Abbas (Allah be pleased with them) said: I regard everything like food (so far as this principle is concerned)}}
\hadithdefcmd{muslim}{3840}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏\hadithno{3840}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who buys foodgrain should not sell it until he has taken full possession of it}}
\hadithdefcmd{muslim}{3841}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَبْتَاعُ الطَّعَامَ فَيَبْعَثُ عَلَيْنَا مَنْ يَأْمُرُنَا بِانْتِقَالِهِ مِنَ الْمَكَانِ الَّذِي ابْتَعْنَاهُ فِيهِ إِلَى مَكَانٍ سِوَاهُ قَبْلَ أَنْ نَبِيعَهُ ‏.‏\hadithno{3841}\hadithtrans{Ibn Umar (Allah be pleased with them) reported:We used to buy foodgrains during the lifetime of Allah's Messenger (ﷺ). He (the Holy Prophet) would then send to us one who commanded us to take them (the foodgrains) to a place other than the one where we had bought them before we sold it}}
\hadithdefcmd{muslim}{3843}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اشْتَرَى طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ وَيَقْبِضَهُ ‏"‏ ‏.‏\hadithno{3843}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who bought foodgrain should not sell it until he had taken full possession of it (after measuring it)}}
\hadithdefcmd{muslim}{3844}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَلِيُّ بْنُ حُجْرٍ، قَالَ يَحْيَى أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، وَقَالَ عَلِيٌّ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَقْبِضَهُ ‏"‏ ‏.‏\hadithno{3844}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying,:He who bought foodgrain should not sell it until he had taken possession of it}}
\hadithdefcmd{muslim}{3846}{\hadithno{3846}\hadithtrans{}}
\hadithdefcmd{muslim}{3847}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ أَبَاهُ، قَالَ قَدْ رَأَيْتُ النَّاسَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا ابْتَاعُوا الطَّعَامَ جِزَافًا يُضْرَبُونَ فِي أَنْ يَبِيعُوهُ فِي مَكَانِهِمْ وَذَلِكَ حَتَّى يُئْوُوهُ إِلَى رِحَالِهِمْ ‏.‏ قَالَ ابْنُ شِهَابٍ وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّ أَبَاهُ كَانَ يَشْتَرِي الطَّعَامَ جِزَافًا فَيَحْمِلُهُ إِلَى أَهْلِهِ ‏.‏\hadithno{3847}\hadithtrans{Salim b. 'Abdullah (Allah be pleased with them) reported his father havingsaid this:I saw people being beaten during the lifetime of Allah's Messenger (ﷺ) in case they bought the foodgrain in bulk, and then sold them at that spot before taking it to their places. This hadith is narrated on the authority of 'Ubaidullah b. Abdullah b. 'Umar through another chain of transmitters (and the words are):" His father (Ibn 'Umar) used to buy foodgrains in bulk and then carried them to his people}}
\hadithdefcmd{muslim}{3848}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اشْتَرَى طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَكْتَالَهُ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ ‏"‏ مَنِ ابْتَاعَ ‏"‏ ‏.‏\hadithno{3848}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who bought foodgrain should not sell it until he had measured it. In the narration of Abu Bakr there the word is Ibta' instead of Ishtara}}
\hadithdefcmd{muslim}{3849}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ الْمَخْزُومِيُّ، حَدَّثَنَا الضَّحَّاكُ، بْنُ عُثْمَانَ عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ لِمَرْوَانَ أَحْلَلْتَ بَيْعَ الرِّبَا ‏.‏ فَقَالَ مَرْوَانُ مَا فَعَلْتُ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ أَحْلَلْتَ بَيْعَ الصِّكَاكِ وَقَدْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الطَّعَامِ حَتَّى يُسْتَوْفَى ‏.‏ قَالَ فَخَطَبَ مَرْوَانُ النَّاسَ فَنَهَى عَنْ بَيْعِهَا ‏.‏ قَالَ سُلَيْمَانُ فَنَظَرْتُ إِلَى حَرَسٍ يَأْخُذُونَهَا مِنْ أَيْدِي النَّاسِ ‏.‏\hadithno{3849}\hadithtrans{Abu Huraira (Allah be please with him) is reported to have said to Marwan:Have you made lawful the transactions involving interest? Thereupon Marwan said: I have not done that. Thereupon Abu Huraira (ﷺ) said: You have made lawful the transactions with the help of documents only, whereas Allah's Messenger (ﷺ) forbade the transaction of foodgrains until full possession is taken of them. Marwan then addressed the people and forbade them to enter into such transactions (as are done with the help of documents). Sulaiman said: I saw the sentinels snatching (these documents) from the people}}
\hadithdefcmd{muslim}{3850}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا ابْتَعْتَ طَعَامًا فَلاَ تَبِعْهُ حَتَّى تَسْتَوْفِيَهُ ‏"‏ ‏.‏\hadithno{3850}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:When you purchase foodgrains, do not sell them until you have taken possession of them}}
\hadithdefcmd{muslim}{3851}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي ابْنُ جُرَيْجٍ، أَنَّ أَبَا الزُّبَيْرِ، أَخْبَرَهُ قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الصُّبْرَةِ مِنَ التَّمْرِ لاَ يُعْلَمُ مَكِيلَتُهَا بِالْكَيْلِ الْمُسَمَّى مِنَ التَّمْرِ ‏.‏\hadithno{3851}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) is reported to have said that Allah's Messenger (ﷺ) forbade the sale of a heap of dates the weight of which is unknown in accordance with the known weight of dates}}
\hadithdefcmd{muslim}{3852}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ مِنَ التَّمْرِ ‏.‏ فِي آخِرِ الْحَدِيثِ ‏.‏\hadithno{3852}\hadithtrans{This hadith is narrated on the authority of Jabir b. Abdullah (Allah be pleased with them) but with this variation that no mention is made of the dates (which one finds) at the end of the previous hadith}}
\hadithdefcmd{muslim}{3853}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ كُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ عَلَى صَاحِبِهِ مَا لَمْ يَتَفَرَّقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{3853}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:Both parties in a business transaction have the right to annul it so long as they have not separated; except in transactions which have been made subject to the right of parties to annul them}}
\hadithdefcmd{muslim}{3854}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي كُلُّهُمْ، عَنْ عُبَيْدِ، اللَّهِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح. وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - جَمِيعًا عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح. وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى، بْنُ سَعِيدٍ ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِ مَالِكٍ عَنْ نَافِعٍ ‏.‏\hadithno{3854}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar (Allah be pleased with them) through another chain of transmitters}}
\hadithdefcmd{muslim}{3855}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا تَبَايَعَ الرَّجُلاَنِ فَكُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا وَكَانَا جَمِيعًا أَوْ يُخَيِّرُ أَحَدُهُمَا الآخَرَ فَإِنْ خَيَّرَ أَحَدُهُمَا الآخَرَ فَتَبَايَعَا عَلَى ذَلِكَ فَقَدْ وَجَبَ الْبَيْعُ وَإِنْ تَفَرَّقَا بَعْدَ أَنْ تَبَايَعَا وَلَمْ يَتْرُكْ وَاحِدٌ مِنْهُمَا الْبَيْعَ فَقَدْ وَجَبَ الْبَيْعُ ‏"‏ ‏\hadithno{3855}\hadithtrans{Ibn 'Umar (Allah be pleased with thcm) reported Allah's Messenger (ﷺ) as saying:When two persons enter into a transaction, each of them has the right to annul it so long as they are not separated and are together (at the place of transaction) ; or if one gives the other the right (to annul the transaction) But if one gives the other the option, the transaction is made on this condition (i. e. one has the right to annul the transaction), it becomes binding. And if they are separated after they have made the bargain and none of them annulled it, even then the transaction is binding}}
\hadithdefcmd{muslim}{3856}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنْ سُفْيَانَ، - قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ ابْنِ جُرَيْجٍ، قَالَ أَمْلَى عَلَىَّ نَافِعٌ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَبَايَعَ الْمُتَبَايِعَانِ بِالْبَيْعِ فَكُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ مِنْ بَيْعِهِ مَا لَمْ يَتَفَرَّقَا أَوْ يَكُونُ بَيْعُهُمَا عَنْ خِيَارٍ فَإِذَا كَانَ بَيْعُهُمَا عَنْ خِيَارٍ فَقَدْ وَجَبَ ‏"‏ ‏.‏ زَادَ ابْنُ أَبِي عُمَرَ فِي رِوَايَتِهِ قَالَ نَافِعٌ فَكَانَ إِذَا بَايَعَ رَجُلاً فَأَرَادَ أَنْ لاَ يُقِيلَهُ قَامَ فَمَشَى هُنَيَّةً ثُمَّ رَجَعَ إِلَيْهِ ‏.‏\hadithno{3856}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:When two persons enter into a transac. tion, each one of them has the right to annul it so long as they are not separated, or their transaction gives one another (as a condition) the right of annulling, and if their transaction, has the right of annulling it the transaction becomes binding. Ibn Abi Umar made this addition that whenever he (Ibn Umar) entered into a transaction with a person with the intention of not breaking it, he walked a while and then returned to him}}
\hadithdefcmd{muslim}{3857}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، و يَحْيَى بْنُ أَيُّوبَ وَقُتَيْبَةُ وَابْنُ حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ، عُمَرَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ بَيِّعَيْنِ لاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا إِلاَّ بَيْعُ الْخِيَارِ ‏"‏ ‏.‏\hadithno{3857}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) as saying:There is no transaction between two persons entering a transaction until they separate, but only when there is an option to annul it}}
\hadithdefcmd{muslim}{3858}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا عَمْرُو بْنُ، عَلِيٍّ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا وَإِنْ كَذَبَا وَكَتَمَا مُحِقَتْ بَرَكَةُ بَيْعِهِمَا ‏"‏ ‏.‏\hadithno{3858}\hadithtrans{Hakim b. Hazim (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Both parties in a business transaction have the right to annul it so long as they have not separated; and if they speak the truth and make everything clear they will be blessed in their transaction; but if they tell a lie and conceal anything the blessing on their transaction will be blotted out}}
\hadithdefcmd{muslim}{3859}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا هَمَّامٌ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الْحَارِثِ، يُحَدِّثُ عَنْ حَكِيمِ بْنِ حِزَامٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏ قَالَ مُسْلِمُ بْنُ الْحَجَّاجِ وُلِدَ حَكِيمُ بْنُ حِزَامٍ فِي جَوْفِ الْكَعْبَةِ وَعَاشَ مِائَةً وَعِشْرِينَ سَنَةً ‏.‏\hadithno{3859}\hadithtrans{A hadith like this has been transmitted on the authority of Hakim b. Hizam (Imam Muslim) said:Hakim b. Hizam was born inside the Ka'ba and lived for one hundred and twenty years}}
\hadithdefcmd{muslim}{3860}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ، عُمَرَ يَقُولُ ذَكَرَ رَجُلٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ يُخْدَعُ فِي الْبُيُوعِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَايَعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏ ‏.‏ فَكَانَ إِذَا بَايَعَ يَقُولُ لاَ خِيَابَةَ‏.‏\hadithno{3860}\hadithtrans{Abdullah b. Dinar narrated that he heard Ibn 'Umar (Allah be pleased with them) saying:A man mentioned to the Messenger of Allah (ﷺ) that he was deceived in a business transaction, whereupon Allah's Messenger (ﷺ) said: When you enter into a transaction, say: There should be no attempt to deceive}}
\hadithdefcmd{muslim}{3861}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَلَيْسَ فِي حَدِيثِهِمَا فَكَانَ إِذَا بَايَعَ يَقُولُ لاَ خِيَابَةَ ‏.‏\hadithno{3861}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah b. Dinar with the same chain of transmitters but these words are not found in it." When he buys he should say:There should be no attempt to deceive}}
\hadithdefcmd{muslim}{3862}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهَا نَهَى الْبَائِعَ وَالْمُبْتَاعَ\hadithno{3862}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) forbade the sale of fruits until they were clearly in good condition, he forbade it both to the seller and to the buyer}}
\hadithdefcmd{muslim}{3863}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{3863}\hadithtrans{Another chain on the authority of Ibn 'Umar narrated the same as the above hadith}}
\hadithdefcmd{muslim}{3864}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ النَّخْلِ حَتَّى يَزْهُوَ وَعَنِ السُّنْبُلِ حَتَّى يَبْيَضَّ وَيَأْمَنَ الْعَاهَةَ نَهَى الْبَائِعَ وَالْمُشْتَرِيَ ‏.‏\hadithno{3864}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) forbade the sale of palm-trees (i. e. their trults) until the dates began to ripen, and ears of corn until they were white and were safe from blight. He forbade the seller and the buyer}}
\hadithdefcmd{muslim}{3865}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَبْتَاعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ وَتَذْهَبَ عَنْهُ الآفَةُ قَالَ يَبْدُوَ صَلاَحُهُ حُمْرَتُهُ وَصُفْرَتُهُ ‏.‏\hadithno{3865}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:Do not buy fruit until its good condition becomes clear, and (the danger) of blight is no more. He said: Its good condition becoming clear implies that it becomes red or yellow}}
\hadithdefcmd{muslim}{3866}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ يَحْيَى، بِهَذَا الإِسْنَادِ حَتَّى يَبْدُوَ صَلاَحُهُ لَمْ يَذْكُرْ مَا بَعْدَهُ\hadithno{3866}\hadithtrans{This hadith is reported or the authority of Yahya with the same chain of transmitters up to" until its good condition becomes clear," but lie did not mention what follows (these words)}}
\hadithdefcmd{muslim}{3867}{حَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ عَبْدِ الْوَهَّابِ ‏.‏\hadithno{3867}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{3868}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، حَدَّثَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ مَالِكٍ وَعُبَيْدِ اللَّهِ ‏.‏\hadithno{3868}\hadithtrans{Nafi, reported on the authority of Ibn Umar (Allah be pleased with them) a hadith like that narrated before}}
\hadithdefcmd{muslim}{3869}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبِيعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ ‏"‏ ‏\hadithno{3869}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger' (ﷺ) as saying:Do not buy fruits (on the trees) until their good condition becomes clear}}
\hadithdefcmd{muslim}{3870}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ وَزَادَ فِي حَدِيثِ شُعْبَةَ فَقِيلَ لاِبْنِ عُمَرَ مَا صَلاَحُهُ قَالَ تَذْهَبُ عَاهَتُهُ ‏.‏\hadithno{3870}\hadithtrans{In the hadith transmitted on the authority of Shu'ba it was stated that Ibn Umar (Allah be pleased with them) was asked what good condition implied. He said:When (the danger of) blight is no more}}
\hadithdefcmd{muslim}{3871}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، ح. وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى - أَوْ نَهَانَا - رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الثَّمَرِ حَتَّى يَطِيبَ ‏.‏\hadithno{3871}\hadithtrans{Jabir (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade (or forbade us) the sale of fruits until they are ripe in a good condition}}
\hadithdefcmd{muslim}{3872}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا رَوْحٌ، قَالاَ حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ ‏.‏\hadithno{3872}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) forbidding the sale of fruit until its good condition is obvious}}
\hadithdefcmd{muslim}{3873}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ عَنْ بَيْعِ النَّخْلِ، فَقَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ النَّخْلِ حَتَّى يَأْكُلَ مِنْهُ أَوْ يُؤْكَلَ وَحَتَّى يُوزَنَ ‏.‏ قَالَ فَقُلْتُ مَا يُوزَنُ فَقَالَ رَجُلٌ عِنْدَهُ حَتَّى يَحْزَرَ ‏.‏\hadithno{3873}\hadithtrans{Abu Bakhtari reported:I asked Ibn 'Abbas (Allah be pleased with them) about the sale of dates. He said: Allah's Messenger (ﷺ) forbade the sale of dates of the trees until one eats them or they are eaten (i. e. they are fit to be eaten) or until they are weighed (or measured). I said: What does it imply:" Until it is weighed"? Thereupon a person who was with him (Ibn Abbas) said: Until he is able to keep it with him (after plucking them)}}
\hadithdefcmd{muslim}{3874}{حَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي، نُعْمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبْتَاعُوا الثِّمَارَ حَتَّى يَبْدُوَ صَلاَحُهَا ‏"‏ ‏.‏\hadithno{3874}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Do not sell the fruits until their good condition becomes evident}}
\hadithdefcmd{muslim}{3875}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ وَزُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لَهُمَا - قَالاَ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ وَعَنْ بَيْعِ الثَّمَرِ بِالتَّمْرِ ‏.‏\hadithno{3875}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) forbidding the sale of fruits until their good condition becomes evident and the purchase of dates for dates}}
\hadithdefcmd{muslim}{3876}{قَالَ ابْنُ عُمَرَ وَحَدَّثَنَا زَيْدُ بْنُ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا ‏.‏ زَادَ ابْنُ نُمَيْرٍ فِي رِوَايَتِهِ أَنْ تُبَاعَ ‏.‏\hadithno{3876}\hadithtrans{Zaid b. Thabit (Allah be pleased with him) said that Allah's Messenger (ﷺ) gave a concession in case of the sale known as al-araya, there is an addition of the word an tuba'a in the hadith transmitted by Ibn Numair}}
\hadithdefcmd{muslim}{3877}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، - وَاللَّفْظُ لِحَرْمَلَةَ - قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبْتَاعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ وَلاَ تَبْتَاعُوا الثَّمَرَ بِالتَّمْرِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَحَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ سَوَاءً ‏.‏\hadithno{3877}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Do not buy the fruit until their condition is clear, and do not buy the fresh dates. A hadith like this has been reported by Ibn 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{3878}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْمُزَابَنَةِ وَالْمُحَاقَلَةِ وَالْمُزَابَنَةُ أَنْ يُبَاعَ ثَمَرُ النَّخْلِ بِالتَّمْرِ وَالْمُحَاقَلَةُ أَنْ يُبَاعَ الزَّرْعُ بِالْقَمْحِ وَاسْتِكْرَاءُ الأَرْضِ بِالْقَمْحِ ‏.‏ قَالَ وَأَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ تَبْتَاعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ وَلاَ تَبْتَاعُوا الثَّمَرَ بِالتَّمْرِ ‏"‏ ‏.‏ وَقَالَ سَالِمٌ أَخْبَرَنِي عَبْدُ اللَّهِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ رَخَّصَ بَعْدَ ذَلِكَ فِي بَيْعِ الْعَرِيَّةِ بِالرُّطَبِ أَوْ بِالتَّمْرِ وَلَمْ يُرَخِّصْ فِي غَيْرِ ذَلِكَ\hadithno{3878}\hadithtrans{Sa'id b. al-Musayyib said that Allah's Messenger (ﷺ) forbade the transaction of Af Muzabana and Muhaqala. Muzabana means that fresh dates on the trees should be sold against dry dates. Muhaqala implies that the wheat in the ear should be sold against the wheat and getting the land on rent for the wheat (produced in it). He (the narrator) said that the Prophet (ﷺ) had aid:Do not sell fresh fruits on the trees until their good condition becomes manifest, and do not sell fresh dates on the trees against dry dates. Salim said: Abdullah informed me on the authority of Zaid b. Thabit, Allah's Messenger (ﷺ) having given concession afterwards in case of ariyya transactions by which dry dates can be exchanged with fresh dates, but he did not permit it in other cases}}
\hadithdefcmd{muslim}{3879}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ زَيْدِ، بْنِ ثَابِتٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ لِصَاحِبِ الْعَرِيَّةِ أَنْ يَبِيعَهَا بِخَرْصِهَا مِنَ التَّمْرِ ‏.‏\hadithno{3879}\hadithtrans{Zaid b. Thabit (Allah be pleased with him) reported Allah's Messenger (may peace he upon him) having given concession in case of 'ariyya for selling dry dates (with) fresh dates after measuring them out}}
\hadithdefcmd{muslim}{3880}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَخْبَرَنِي نَافِعٌ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يُحَدِّثُ أَنَّ زَيْدَ بْنَ ثَابِتٍ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الْعَرِيَّةِ يَأْخُذُهَا أَهْلُ الْبَيْتِ بِخَرْصِهَا تَمْرًا يَأْكُلُونَهَا رُطَبًا ‏.‏\hadithno{3880}\hadithtrans{Zaid b. Thabit reported that Allah's Messenger (ﷺ) give concession in case of 'ariyya transactions according to which the members of the household give dry dates according to a measure and then eat fresh dates (in exchange for it)}}
\hadithdefcmd{muslim}{3881}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَنِي نَافِعٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3881}\hadithtrans{A hadith like this has been narrated on the authority of Nafi' with the same chain of transmitters}}
\hadithdefcmd{muslim}{3882}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ وَالْعَرِيَّةُ النَّخْلَةُ تُجْعَلُ لِلْقَوْمِ فَيَبِيعُونَهَا بِخَرْصِهَا تَمْرًا ‏.‏\hadithno{3882}\hadithtrans{Yahya b. Sa'id reported this hadith with the same chain of transmitters but with this change:'Ariyya implies that date-palm trees should be donated to the people and then they sell it with a measure of dry dates}}
\hadithdefcmd{muslim}{3883}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، حَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرِيَّةِ بِخَرْصِهَا تَمْرًا ‏.‏ قَالَ يَحْيَى الْعَرِيَّةُ أَنْ يَشْتَرِيَ الرَّجُلُ ثَمَرَ النَّخَلاَتِ لِطَعَامِ أَهْلِهِ رُطَبًا بِخَرْصِهَا تَمْرًا ‏.‏\hadithno{3883}\hadithtrans{Zaid b Thabit (Allah be pleased with him) reported that Allah's Messenger (ﷺ) gave concession in case of al-'ariyya transactions (for exchanging dates) for dates with measure. Yahya said:'Ariyya implies that a person should buy fresh dates on the tree for his family to eat against a measure of dry dates}}
\hadithdefcmd{muslim}{3884}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا أَنْ تُبَاعَ بِخَرْصِهَا كَيْلاً ‏.‏\hadithno{3884}\hadithtrans{Zaid b. Thabit (Allah be pleased with him) reported Allah's Messenger (ﷺ) granting concession in case of 'ariyya transactions and that implies selling of (dry dates for fresh dates) according to a measure}}
\hadithdefcmd{muslim}{3885}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ وَقَالَ أَنْ تُؤْخَذَ بِخَرْصِهَا ‏.‏\hadithno{3885}\hadithtrans{Ubaidullah reported this hadith with a slight change of words on the same authority (as quoted above)}}
\hadithdefcmd{muslim}{3886}{وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، كِلاَهُمَا عَنْ أَيُّوبَ، عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا بِخَرْصِهَا ‏.‏\hadithno{3886}\hadithtrans{Nafi, reported this hadith with the same chain of transmitters stating that Allah's Messengtr (ﷺ) granted concession in case of 'ariyya transactions (for exchange of the same commodity) with measure}}
\hadithdefcmd{muslim}{3887}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ بَعْضِ، أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَهْلِ دَارِهِمْ مِنْهُمْ سَهْلُ بْنُ أَبِي حَثْمَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ بِالتَّمْرِ وَقَالَ ‏ "‏ ذَلِكَ الرِّبَا تِلْكَ الْمُزَابَنَةُ ‏"‏ ‏.‏ إِلاَّ أَنَّهُ رَخَّصَ فِي بَيْعِ الْعَرِيَّةِ النَّخْلَةِ وَالنَّخْلَتَيْنِ يَأْخُذُهَا أَهْلُ الْبَيْتِ بِخَرْصِهَا تَمْرًا يَأْكُلُونَهَا رُطَبًا ‏.‏\hadithno{3887}\hadithtrans{Bashair b. Yasir reported on the authority of some of the Companions of Allah's Messenger (ﷺ) among the members of his family among whom one was Sahl b. Abu Hathma that Allah's Messenger (ﷺ) forbade buying of fresh dates against dry dates and that it is Riba and this is Muzabana, but he made an exemption of 'ariyya (donations) of a tree or two in which case the members of a family sell dry dates and buy fresh dates for eating them}}
\hadithdefcmd{muslim}{3888}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى، بْنِ سَعِيدٍ عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ أَصْحَابِ، رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُمْ قَالُوا رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْعِ الْعَرِيَّةِ بِخَرْصِهَا تَمْرًا ‏.‏\hadithno{3888}\hadithtrans{Bushair b. Yasar reported on the authority of some of the Companion of Allah's Messenger (ﷺ) that he exempted the transactions, of 'ariyya (from the direct exchange of one kind) after measuring the dry dates (in exchange for fresh dates)}}
\hadithdefcmd{muslim}{3889}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ الثَّقَفِيِّ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَنِي بُشَيْرُ بْنُ يَسَارٍ، عَنْ بَعْضِ، أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَهْلِ دَارِهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ عَنْ يَحْيَى غَيْرَ أَنَّ إِسْحَاقَ وَابْنَ الْمُثَنَّى جَعَلاَ مَكَانَ الرِّبَا الزَّبْنَ وَقَالَ ابْنُ أَبِي عُمَرَ الرِّبَا ‏.‏\hadithno{3889}\hadithtrans{Bushair b. Yasir reported on the authority of some of the Companions of Allah's Messenger (may peace be upon hinn) from among the members of his family that he forbade (the direct exchange of a commodity having different qualities) but with the change that Ishaq and Ibn al-Muthanna used the word Zabn in place of Riba and Ibn Abu 'Umar used the word Riba (interest)}}
\hadithdefcmd{muslim}{3890}{وَحَدَّثَنَاهُ عَمْرٌو النَّاقِدُ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ، سَعِيدٍ عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{3890}\hadithtrans{A hadith like this has been narrated on the authority of Sahl b. Abu Hathma}}
\hadithdefcmd{muslim}{3891}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَحَسَنٌ الْحُلْوَانِيُّ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ، بْنِ كَثِيرٍ حَدَّثَنِي بُشَيْرُ بْنُ يَسَارٍ، مَوْلَى بَنِي حَارِثَةَ أَنَّ رَافِعَ بْنَ خَدِيجٍ، وَسَهْلَ بْنَ أَبِي حَثْمَةَ، حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ الثَّمَرِ بِالتَّمْرِ إِلاَّ أَصْحَابَ الْعَرَايَا فَإِنَّهُ قَدْ أَذِنَ لَهُمْ ‏.‏\hadithno{3891}\hadithtrans{Sahl b. Abu Hathma reported Allah's Messenger (ﷺ) having forbidden Muzabana, i. e. exchange of fresh dates with dry dates. except in case of those to whom donations of some trees have been made. It is for them that concession has been given}}
\hadithdefcmd{muslim}{3892}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ قُلْتُ لِمَالِكٍ حَدَّثَكَ دَاوُدُ بْنُ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، - مَوْلَى ابْنِ أَبِي أَحْمَدَ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا بِخَرْصِهَا فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ أَوْ فِي خَمْسَةِ - يَشُكُّ دَاوُدُ قَالَ خَمْسَةٌ أَوْ دُونَ خَمْسَةٍ - قَالَ نَعَمْ ‏.‏\hadithno{3892}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) having given exemption of 'ariyya transactions measuring less than five wasqs or up to five wasqs (the narrator Dawud is in doubt whether it was five or less than five)}}
\hadithdefcmd{muslim}{3893}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ وَالْمُزَابَنَةُ بَيْعُ الثَّمَرِ بِالتَّمْرِ كَيْلاً وَبَيْعُ الْكَرْمِ بِالزَّبِيبِ كَيْلاً ‏.‏\hadithno{3893}\hadithtrans{Ibn Umar (Allah be pleased them) reported Allah's Messenger (ﷺ) having forbidden Muzabana, and Muzabana implies the selling of fresh dates for dry dates by measuring them out and the selling of raisins by measure for grapes}}
\hadithdefcmd{muslim}{3894}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ، بِشْرٍ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ بَيْعِ ثَمَرِ النَّخْلِ بِالتَّمْرِ كَيْلاً وَبَيْعِ الْعِنَبِ بِالزَّبِيبِ كَيْلاً وَبَيْعِ الزَّرْعِ بِالْحِنْطَةِ كَيْلاً ‏.‏\hadithno{3894}\hadithtrans{Abdullah (b. Umar) reported that Allah's Apostle (ﷺ) forbade Muzabana, i. e. buying of fresh dates (on) the trees for dry dates by measure, and the buying of grapes for raisins by measure and the selling of field of corn for corn by measure}}
\hadithdefcmd{muslim}{3895}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ مِثْلَهُ\hadithno{3895}\hadithtrans{A hadith like this has been narrated on the authority of 'Ubaidullah with the same chain of transmitters}}
\hadithdefcmd{muslim}{3896}{حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، وَحُسَيْنُ بْنُ عِيسَى، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُزَابَنَةِ وَالْمُزَابَنَةُ بَيْعُ ثَمَرِ النَّخْلِ بِالتَّمْرِ كَيْلاً وَبَيْعُ الزَّبِيبِ بِالْعِنَبِ كَيْلاً وَعَنْ كُلِّ ثَمَرٍ بِخَرْصِهِ ‏.‏\hadithno{3896}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) having forbidden Muzabana, and Muzabana is the selling of dry dates by measure for fresh dates and the selling of raisins by measure for grapes and selling of all Ports of fruits on the basis of calculation}}
\hadithdefcmd{muslim}{3897}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ - عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ وَالْمُزَابَنَةُ أَنْ يُبَاعَ مَا فِي رُءُوسِ النَّخْلِ بِتَمْرٍ بِكَيْلٍ مُسَمًّى إِنْ زَادَ فَلِي وَإِنْ نَقَصَ فَعَلَىَّ ‏.‏\hadithno{3897}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) having forbidden Muzabana, and Muzabana implies the selling of dry dates for fresh dates on the tree with a definite measure (making it clear) that in case it increases, it belongs to me and if it is less, it is my responsibility}}
\hadithdefcmd{muslim}{3898}{وَحَدَّثَنَاهُ أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3898}\hadithtrans{A hadith like this has been transmitted on the authority of Ayyub}}
\hadithdefcmd{muslim}{3899}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُزَابَنَةِ أَنْ يَبِيعَ ثَمَرَ حَائِطِهِ إِنْ كَانَتْ نَخْلاً بِتَمْرٍ كَيْلاً وَإِنْ كَانَ كَرْمًا أَنْ يَبِيعَهُ بِزَبِيبٍ كَيْلاً وَإِنْ كَانَ زَرْعًا أَنْ يَبِيعَهُ بِكَيْلِ طَعَامٍ ‏.‏ نَهَى عَنْ ذَلِكَ كُلِّهِ ‏.‏ وَفِي رِوَايَةِ قُتَيْبَةَ أَوْ كَانَ زَرْعًا\hadithno{3899}\hadithtrans{Abdullah (b. Umar) (Allah be pleased with them) reported Allah's Messenger (ﷺ) having forbidden Mazabana, and it implies that one should sell the fresh fruits of his orchard (for dry fruits) or, if it is fresh dates, for dry dates with a measure, or if it is grapes for raisins or if it is corn in the field for dry corn with a measure He (the Holy Prophet) in fact forbade all such transactions. Qutaiba has narrated it with a slight variation of words}}
\hadithdefcmd{muslim}{3900}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي يُونُسُ، ح وَحَدَّثَنَاهُ ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنِي الضَّحَّاكُ، ح وَحَدَّثَنِيهِ سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، حَدَّثَنِي مُوسَى بْنُ عُقْبَةَ، كُلُّهُمْ عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِهِمْ\hadithno{3900}\hadithtrans{This hadith has been narrated on the authority of Nafi with another chain of transmitters}}
\hadithdefcmd{muslim}{3901}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ بَاعَ نَخْلاً قَدْ أُبِّرَتْ فَثَمَرَتُهَا لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏\hadithno{3901}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:If anyone buys palm-trees after they have been fecundated the fruit belongs to the seller unless the buyer makes a proviso}}
\hadithdefcmd{muslim}{3902}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، جَمِيعًا عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا نَخْلٍ اشْتُرِيَ أُصُولُهَا وَقَدْ أُبِّرَتْ فَإِنَّ ثَمَرَهَا لِلَّذِي أَبَّرَهَا إِلاَّ أَنْ يَشْتَرِطَ الَّذِي اشْتَرَاهَا‏"‏ ‏.‏\hadithno{3902}\hadithtrans{Nafi reported on the authority of Ibn Umar (Allah be pleased with them) that the Messenger of Allah (ﷺ) said:Whichever tree is bought with its roots, and if it is fecundatedits fruit would belong to one who has grafted it except when the provision is laid down by the buyer}}
\hadithdefcmd{muslim}{3903}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرِئٍ أَبَّرَ نَخْلاً ثُمَّ بَاعَ أَصْلَهَا فَلِلَّذِي أَبَّرَ ثَمَرُ النَّخْلِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏\hadithno{3903}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:Whosoever grafts the tree and then sells its roots, its fruit will belong to one who grafts it except when provision is laid down by the buyer}}
\hadithdefcmd{muslim}{3904}{وَحَدَّثَنَاهُ أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، كِلاَهُمَا عَنْ أَيُّوبَ، عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3904}\hadithtrans{This hadith has been narrated on the authority of Nafi, with the same chain of transmitters}}
\hadithdefcmd{muslim}{3905}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ابْتَاعَ نَخْلاً بَعْدَ أَنْ تُؤَبَّرَ فَثَمَرَتُهَا لِلَّذِي بَاعَهَا إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ وَمَنِ ابْتَاعَ عَبْدًا فَمَالُهُ لِلَّذِي بَاعَهُ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏\hadithno{3905}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported Allah's Massenger (ﷺ) as saying:He who buys a tree after it has been fecundated, its fruit belongs to one who sells it except when the provision has been laid down by the buyer (that it will belong to him), and he who buys a slave, his property belongs to one who sells him except when a provision has been laid down by the buyer (that it will be transferred to him with the slave)}}
\hadithdefcmd{muslim}{3906}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3906}\hadithtrans{A hadith like this has been narrated on the authority of al Zuhri}}
\hadithdefcmd{muslim}{3907}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ أَبَاهُ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِمِثْلِهِ ‏.‏\hadithno{3907}\hadithtrans{Ibn Umar reported on the authority of his father as Allah's Apostle (ﷺ) saying so}}
\hadithdefcmd{muslim}{3908}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا جَمِيعًا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُخَابَرَةِ وَعَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ وَلاَ يُبَاعُ إِلاَّ بِالدِّينَارِ وَالدِّرْهَمِ إِلاَّ الْعَرَايَا ‏.‏\hadithno{3908}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported that Allah's Messenger (ﷺ) had forbidden Muhaqala. and Muzabana, Mukhibara and the sale of fruits until their good condition becomes clear, and (he commanded) that (commodities) should not be sold but for the dinar and dirham except in case of araya}}
\hadithdefcmd{muslim}{3909}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، وَأَبِي، الزُّبَيْرِ أَنَّهُمَا سَمِعَا جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{3909}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported that Allah's Messenger (ﷺ) forbade the types of sales as described before}}
\hadithdefcmd{muslim}{3910}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا مَخْلَدُ بْنُ يَزِيدَ الْجَزَرِيُّ، حَدَّثَنَا ابْنُ، جُرَيْجٍ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُخَابَرَةِ وَالْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَعَنْ بَيْعِ الثَّمَرَةِ حَتَّى تُطْعِمَ وَلاَ تُبَاعُ إِلاَّ بِالدَّرَاهِمِ وَالدَّنَانِيرِ إِلاَّ الْعَرَايَا ‏.‏ قَالَ عَطَاءٌ فَسَّرَ لَنَا جَابِرٌ قَالَ أَمَّا الْمُخَابَرَةُ فَالأَرْضُ الْبَيْضَاءُ يَدْفَعُهَا الرَّجُلُ إِلَى الرَّجُلِ فَيُنْفِقُ فِيهَا ثُمَّ يَأْخُذُ مِنَ الثَّمَرِ ‏.‏ وَزَعَمَ أَنَّ الْمُزَابَنَةَ بَيْعُ الرُّطَبِ فِي النَّخْلِ بِالتَّمْرِ كَيْلاً ‏.‏ وَالْمُحَاقَلَةُ فِي الزَّرْعِ عَلَى نَحْوِ ذَلِكَ يَبِيعُ الزَّرْعَ الْقَائِمَ بِالْحَبِّ كَيْلاً ‏.‏\hadithno{3910}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported that Allah's Messenger (ﷺ) forbade Mukhabara and Muhaqala, and Muzabana, and the sale of the fruit until it is fit for eating, and its sale but with dirham and dinar. Exception is made in case of 'araya. Ata' said:Jabir explained (these terms) for us. As for Mukhabara it is this that a wasteland is given by a person to another and he makes an investment in it and then gets a share in the produce. According to him (Jabir), Muzabana is the sell of fresh dates on the tree for dry dates with a measure, and Muhaqala in agriculture implies that one should sell the standing crop for grains with a measure}}
\hadithdefcmd{muslim}{3911}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، كِلاَهُمَا عَنْ زَكَرِيَّاءَ، قَالَ ابْنُ أَبِي خَلَفٍ حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، حَدَّثَنَا أَبُو الْوَلِيدِ الْمَكِّيُّ، وَهُوَ جَالِسٌ عِنْدَ عَطَاءِ بْنِ أَبِي رَبَاحٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُخَابَرَةِ وَأَنْ تُشْتَرَى النَّخْلُ حَتَّى تُشْقِهَ - وَالإِشْقَاهُ أَنْ يَحْمَرَّ أَوْ يَصْفَرَّ أَوْ يُؤْكَلَ مِنْهُ شَىْءٌ - وَالْمُحَاقَلَةُ أَنْ يُبَاعَ الْحَقْلُ بِكَيْلٍ مِنَ الطَّعَامِ مَعْلُومٍ وَالْمُزَابَنَةُ أَنْ يُبَاعَ النَّخْلُ بِأَوْسَاقٍ مِنَ التَّمْرِ وَالْمُخَابَرَةُ الثُّلُثُ وَالرُّبُعُ وَأَشْبَاهُ ذَلِكَ ‏.‏ قَالَ زَيْدٌ قُلْتُ لِعَطَاءِ بْنِ أَبِي رَبَاحٍ أَسَمِعْتَ جَابِرَ بْنَ عَبْدِ اللَّهِ يَذْكُرُ هَذَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏\hadithno{3911}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) forbidding Muhaqala, and Muzabana, and Mukhabara, and the buying of date-palm until its fruit is ripened (ripening means that its colour becomes red or yellow, or it is fit for being eaten). And Muhaqala implies that crops in the field are bought for grains according to a customary measure. Muzabana implies that date-palm should be sold for dry dates by measuring them with wisqs, and al-Mukhabara is (a share), maybe one-third or one-fourth (in produce) or something like it. Zaid (one of the narrators) said to Ata' b. Abu Rabah (the other narrator):Did You bear Jabir b. Abdullah (Allah be pleased with them) making a mention of it that he had heard it directly from Allah's Messenger (ﷺ)? He said: Yes}}
\hadithdefcmd{muslim}{3912}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ هَاشِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، حَدَّثَنَا سَعِيدُ بْنُ، مِينَاءَ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُزَابَنَةِ وَالْمُحَاقَلَةِ وَالْمُخَابَرَةِ وَعَنْ بَيْعِ الثَّمَرَةِ حَتَّى تُشْقِحَ ‏.‏ قَالَ قُلْتُ لِسَعِيدٍ مَا تُشْقِحُ قَالَ تَحْمَارُّ وَتَصْفَارُّ وَيُؤْكَلُ مِنْهَا ‏.‏\hadithno{3912}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) forbidding Muzabana and Muhaqala, and Mukhabara, and the sale of fruits until they are ripe. I (the narrator) said to Sa'id (the other narrator):What does ripening imply? He said: It meant that they become red or become yellow and are fit for eating}}
\hadithdefcmd{muslim}{3913}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَمُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، - وَاللَّفْظُ لِعُبَيْدِ اللَّهِ - قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، وَسَعِيدِ بْنِ مِينَاءَ، عَنْ جَابِرِ بْنِ، عَبْدِ اللَّهِ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُعَاوَمَةِ وَالْمُخَابَرَةِ - قَالَ أَحَدُهُمَا بَيْعُ السِّنِينَ هِيَ الْمُعَاوَمَةُ - وَعَنِ الثُّنْيَا وَرَخَّصَ فِي الْعَرَايَا ‏.‏\hadithno{3913}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) forbidding Muhaqala and Muzabana and Mu'awama and Mukhabara. (One of the narrators) 'said:Sale years ahead is Mu'awama, and making exceptional but he made an exemption of araya}}
\hadithdefcmd{muslim}{3914}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ لاَ يَذْكُرُ بَيْعُ السِّنِينَ هِيَ الْمُعَاوَمَةُ ‏.‏\hadithno{3914}\hadithtrans{A hadith like this has been narrated on the authority of Jabir (Allah be pleased with him) from Allah's Apostle (ﷺ). but he made no mention of transactions years (ahead) implying Mu'awama}}
\hadithdefcmd{muslim}{3915}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا رَبَاحُ بْنُ، أَبِي مَعْرُوفٍ قَالَ سَمِعْتُ عَطَاءً، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كِرَاءِ الأَرْضِ وَعَنْ بَيْعِهَا السِّنِينَ وَعَنْ بَيْعِ الثَّمَرِ حَتَّى يَطِيبَ ‏.‏\hadithno{3915}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported that Allah's Messenger (ﷺ) forbade leasing of land, and selling ahead for years and selling of fruits before they become ripe}}
\hadithdefcmd{muslim}{3916}{وَحَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الأَرْضِ ‏.‏\hadithno{3916}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) having forbidden the renting of land}}
\hadithdefcmd{muslim}{3917}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ، - لَقَبُهُ عَارِمٌ وَهُوَ أَبُو النُّعْمَانِ السَّدُوسِيُّ - حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا مَطَرٌ الْوَرَّاقُ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا فَإِنْ لَمْ يَزْرَعْهَا فَلْيُزْرِعْهَا أَخَاهُ ‏"‏ ‏.‏\hadithno{3917}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who has land should cultivate it himself, but if he does not cultivate it himself, then he should let his brother cultivate it}}
\hadithdefcmd{muslim}{3918}{حَدَّثَنَا الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا هِقْلٌ، - يَعْنِي ابْنَ زِيَادٍ - عَنِ الأَوْزَاعِيِّ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ لِرِجَالٍ فُضُولُ أَرَضِينَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ فَضْلُ أَرْضٍ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا أَخَاهُ فَإِنْ أَبَى فَلْيُمْسِكْ أَرْضَهُ ‏"‏ ‏.‏\hadithno{3918}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported some of the Companions of Allah's Messenger (ﷺ) had surplus of land. Thereupon Allah's Messenger (ﷺ) said:He, who has surplus land (in his possession) should cultivate it, or he should lend it to his brother for benefit, but if he refuses to accept it, he should retain it}}
\hadithdefcmd{muslim}{3919}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ الرَّازِيُّ، حَدَّثَنَا خَالِدٌ، أَخْبَرَنَا الشَّيْبَانِيُّ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُؤْخَذَ لِلأَرْضِ أَجْرٌ أَوْ حَظٌّ ‏.‏\hadithno{3919}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) having forbidden taking of rent or share of land}}
\hadithdefcmd{muslim}{3920}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا فَإِنْ لَمْ يَسْتَطِعْ أَنْ يَزْرَعَهَا وَعَجَزَ عَنْهَا فَلْيَمْنَحْهَا أَخَاهُ الْمُسْلِمَ وَلاَ يُؤَاجِرْهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{3920}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who has land should cultivate it, but if he does not find it possible to cultivate it, or finds himself helpless to do so, he should lend it to his Muslim brother, but he should not accept rent from him}}
\hadithdefcmd{muslim}{3921}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا هَمَّامٌ، قَالَ سَأَلَ سُلَيْمَانُ بْنُ مُوسَى عَطَاءً فَقَالَ أَحَدَّثَكَ جَابِرُ بْنُ عَبْدِ اللَّهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيُزْرِعْهَا أَخَاهُ وَلاَ يُكْرِهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{3921}\hadithtrans{Sulaiman b. Musa asked Ata':Did Jabir b. 'Abdullah (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:" He who has land should cultivate it himself, or let his brother cultivate it, and should not give on rent"? He said: Yes}}
\hadithdefcmd{muslim}{3922}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُخَابَرَةِ ‏.‏\hadithno{3922}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Apostle (ﷺ) having forbidden Mukhabara}}
\hadithdefcmd{muslim}{3923}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا سَلِيمُ بْنُ، حَيَّانَ حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ لَهُ فَضْلُ أَرْضٍ فَلْيَزْرَعْهَا أَوْ لِيُزْرِعْهَا أَخَاهُ وَلاَ تَبِيعُوهَا ‏"‏ ‏.‏ فَقُلْتُ لِسَعِيدٍ مَا قَوْلُهُ وَلاَ تَبِيعُوهَا يَعْنِي الْكِرَاءَ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{3923}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) heard Allah's Messenger (ﷺ) say:He who has surplus of land should either cultivate it himself, or let his brother cultivate it, an should not sell it. I (the narrator) said to Sa'id: What does his statement" do not sell it" mean? Does it imply" rent"? He said: Yes}}
\hadithdefcmd{muslim}{3924}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنَّا نُخَابِرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنُصِيبُ مِنَ الْقِصْرِيِّ وَمِنْ كَذَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ فَلْيُحْرِثْهَا أَخَاهُ وَإِلاَّ فَلْيَدَعْهَا‏"‏ ‏.‏\hadithno{3924}\hadithtrans{Jabir b. 'Abdullah reported:We used to cultivate land on rent during the lifetime of Allah's Apostle (ﷺ) and we got a share out of the grain left in the ears after threshing them and something unspecified. Allah's Messenger (ﷺ) said: He who has land should cultivate it or let his brother till it, otherwise he should leave it}}
\hadithdefcmd{muslim}{3925}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَأَحْمَدُ بْنُ عِيسَى، جَمِيعًا عَنِ ابْنِ وَهْبٍ، - قَالَ ابْنُ عِيسَى حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، - حَدَّثَنِي هِشَامُ بْنُ سَعْدٍ، أَنَّ أَبَا الزُّبَيْرِ الْمَكِّيَّ، حَدَّثَهُ قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كُنَّا فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَأْخُذُ الأَرْضَ بِالثُّلُثِ أَوِ الرُّبُعِ بِالْمَاذِيَانَاتِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ فَقَالَ ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا فَإِنْ لَمْ يَزْرَعْهَا فَلْيَمْنَحْهَا أَخَاهُ فَإِنْ لَمْ يَمْنَحْهَا أَخَاهُ فَلْيُمْسِكْهَا ‏"‏ ‏.‏\hadithno{3925}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported:We used to get land (on rent) during the lifetime of Allah's Messeuge, (ﷺ) with a share of one-third or one-fourth (of the produce from the land irrigated) with the help of canals. Thereupon Allah's Messenger (ﷺ) stood up (to address) and said: HRe who has land should cultivate it, and if he does not cultivate it, he should lend it to his brother, and if he does not lend it to his brother, he should then retain it}}
\hadithdefcmd{muslim}{3926}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُلَيْمَانَ، حَدَّثَنَا أَبُو سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَهَبْهَا أَوْ لِيُعِرْهَا ‏"‏ ‏.‏\hadithno{3926}\hadithtrans{Jabir (Allah he pleased with him) reported:I heard Allah's Apostle (ﷺ) as saying: He who has (surplus) land should donate it (to others), or lend it}}
\hadithdefcmd{muslim}{3927}{وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا أَبُو الْجَوَّابِ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَلْيَزْرَعْهَا أَوْ فَلْيُزْرِعْهَا رَجُلاً ‏"‏ ‏.‏\hadithno{3927}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters, but with a slight change of words}}
\hadithdefcmd{muslim}{3928}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ أَبِي سَلَمَةَ حَدَّثَهُ عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الأَرْضِ ‏.‏ قَالَ بُكَيْرٌ وَحَدَّثَنِي نَافِعٌ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، يَقُولُ كُنَّا نُكْرِي أَرْضَنَا ثُمَّ تَرَكْنَا ذَلِكَ حِينَ سَمِعْنَا حَدِيثَ رَافِعِ بْنِ خَدِيجٍ ‏.‏\hadithno{3928}\hadithtrans{Jabir b. `Abdullah (Allah be pleased with them) reportedthat Allah's Messenger (ﷺ) had forbidden renting of land. Bukair (one of the narrators) said:Nafi` reported to me that he heard Ibn `Umar (Allah be pleased with them) saying: We usedto give land on rent; we then abandoned this practice when we heard the hadith of Rafi` b. Khadij}}
\hadithdefcmd{muslim}{3929}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الأَرْضِ الْبَيْضَاءِ سَنَتَيْنِ أَوْ ثَلاَثًا ‏.‏\hadithno{3929}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Messenger (ﷺ) forbidding the selling (renting of) uncultivated land for two years or three}}
\hadithdefcmd{muslim}{3930}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ سُلَيْمَانَ بْنِ عَتِيقٍ، عَنْ جَابِرٍ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ السِّنِينَ ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبِي شَيْبَةَ عَنْ بَيْعِ الثَّمَرِ سِنِينَ ‏.‏\hadithno{3930}\hadithtrans{Jabir (Allah be pleased with him) reported Allah's Apostle (ﷺ) forbidding selling of (produce) in advance for two years, and in the narmtion of Ibu Abd Shaiba (the words are):" Selling of the fruits (on the tree) in advance for two years}}
\hadithdefcmd{muslim}{3931}{حَدَّثَنَا حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ، حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى بْنِ، أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا أَخَاهُ فَإِنْ أَبَى فَلْيُمْسِكْ أَرْضَهُ ‏"‏ ‏.‏\hadithno{3931}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who has land should cultivate it or lend it to his brother, but if he refuses, he should retain his land}}
\hadithdefcmd{muslim}{3932}{وَحَدَّثَنَا الْحَسَنُ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ، حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، أَنَّ يَزِيدَ بْنَ نُعَيْمٍ، أَخْبَرَهُ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ أَخْبَرَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ الْمُزَابَنَةِ وَالْحُقُولِ ‏.‏ فَقَالَ جَابِرُ بْنُ عَبْدِ اللَّهِ الْمُزَابَنَةُ الثَّمَرُ بِالتَّمْرِ ‏.‏ وَالْحُقُولُ كِرَاءُ الأَرْضِ ‏.‏\hadithno{3932}\hadithtrans{Jabir b. Abdullah (Allah be pleased with them) reported:I heard Allah's Messenger (ﷺ) forbidding Muzabana, and Huqul. Jabir b. Abdullah (Allah be pleased with them) said: Muzabana means the selling of fruits for dry dates and Huqul is the renting of land}}
\hadithdefcmd{muslim}{3933}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏\hadithno{3933}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) forbidding Muhaqala and Muzabana}}
\hadithdefcmd{muslim}{3934}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، أَنَّ أَبَا سُفْيَانَ، مَوْلَى ابْنِ أَبِي أَحْمَدَ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُزَابَنَةِ وَالْمُحَاقَلَةِ ‏.‏ وَالْمُزَابَنَةُ اشْتِرَاءُ الثَّمَرِ فِي رُءُوسِ النَّخْلِ ‏.‏ وَالْمُحَاقَلَةُ كِرَاءُ الأَرْضِ ‏.‏\hadithno{3934}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported Allah's Messenger (ﷺ) having forbidden Mazabana and Muhaqala. Muzibana means the buying of fruits on the trees and Muhaqala is the renting of land}}
\hadithdefcmd{muslim}{3935}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ الْعَتَكِيُّ، قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا وَقَالَ، يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ كُنَّا لاَ نَرَى بِالْخِبْرِ بَأْسًا حَتَّى كَانَ عَامُ أَوَّلَ فَزَعَمَ رَافِعٌ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهُ ‏.‏\hadithno{3935}\hadithtrans{Zaid b. Amr reported:I heard Ibn Umar (Allah be pleased with them) say: We did not see any harm in renting of the land, but as the first year was over Rafi' alleged Allah's Apostle (ﷺ) having forbidden that}}
\hadithdefcmd{muslim}{3936}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، وَإِبْرَاهِيمُ، بْنُ دِينَارٍ قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ أَيُّوبَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنْ عَمْرِو بْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَزَادَ فِي حَدِيثِ ابْنِ عُيَيْنَةَ فَتَرَكْنَاهُ مِنْ أَجْلِهِ ‏.‏\hadithno{3936}\hadithtrans{This hadith has been narrated on the authority of Amr b. Dinar with the same chain of transmitters but (in) the hadith transmitted on the authority of 'Uyainah (the words are):" We abandoned it (renting) on account of that}}
\hadithdefcmd{muslim}{3937}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ أَبِي الْخَلِيلِ، عَنْ مُجَاهِدٍ، قَالَ قَالَ ابْنُ عُمَرَ لَقَدْ مَنَعَنَا رَافِعٌ نَفْعَ أَرْضِنَا ‏.‏\hadithno{3937}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported:Rafi forbade us from benefitting from our land (in the form of rent)}}
\hadithdefcmd{muslim}{3938}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يُكْرِي مَزَارِعَهُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي إِمَارَةِ أَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ وَصَدْرًا مِنْ خِلاَفَةِ مُعَاوِيَةَ حَتَّى بَلَغَهُ فِي آخِرِ خِلاَفَةِ مُعَاوِيَةَ أَنَّ رَافِعَ بْنَ خَدِيجٍ يُحَدِّثُ فِيهَا بِنَهْىٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فَدَخَلَ عَلَيْهِ وَأَنَا مَعَهُ فَسَأَلَهُ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ كِرَاءِ الْمَزَارِعِ ‏.‏ فَتَرَكَهَا ابْنُ عُمَرَ بَعْدُ ‏.‏ وَكَانَ إِذَا سُئِلَ عَنْهَا بَعْدُ قَالَ زَعَمَ رَافِعُ بْنُ خَدِيجٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهَا ‏.‏\hadithno{3938}\hadithtrans{Nafi reported that Ibn Umar (Allah be pleased with them) rented his land during the lifetime of Allah's Messenger (ﷺ) and during the caliphate of Abu Bakr and that of Umar and that of Uthman (Allah be pleased with them) and during the early period of Muawiya's caliphate until at the end of Muawiya's reign, it reached him (Ibn 'Umar) that Rafi b. Khadij (Allah be pleased with him) narratted (a hadith) in which (there was a decree) of prohibition by Allah's Apostle (ﷺ). He (Ibn 'Umar) went to him (Rafi b. Khadij) and I was with him and he asked him, whereupon he said:Allah's Messenger (ﷺ) used to forbid the renting of land. So Ibn Umar (Allah be pleased with them) abandoned it, and subsequently whenever he was asked about it, he said: Rafi b. Khadij (Allah be pleased with him) alleged that Allah's Messenger (ﷺ) forbade it}}
\hadithdefcmd{muslim}{3939}{وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، كِلاَهُمَا عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَزَادَ فِي حَدِيثِ ابْنِ عُلَيَّةَ قَالَ فَتَرَكَهَا ابْنُ عُمَرَ بَعْدَ ذَلِكَ فَكَانَ لاَ يُكْرِيهَا ‏.‏\hadithno{3939}\hadithtrans{This hadith has been narrated on the authority of Ayyub and he made an addition in the hadith narrated by Ibn Ulayya in which he said:Ibn Umar abandoned it afterwards and he did not rent it (the land)}}
\hadithdefcmd{muslim}{3940}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، قَالَ ذَهَبْتُ مَعَ ابْنِ عُمَرَ إِلَى رَافِعِ بْنِ خَدِيجٍ حَتَّى أَتَاهُ بِالْبَلاَطِ فَأَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ ‏.‏\hadithno{3940}\hadithtrans{Nafi reported:I went to Rafi b. Khadij in the company of Ibn 'Umar (All be pleased with them) until he (Ibn 'Umar) came to him at Balat (a place near Prophet's Mosque at Medina) and he (Rafi b. Khadij) informed him that Allah's Messenger (ﷺ) had forbidden the renting of land}}
\hadithdefcmd{muslim}{3941}{وَحَدَّثَنِي ابْنُ أَبِي خَلَفٍ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدٍ، عَنِ الْحَكَمِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ أَتَى رَافِعًا فَذَكَرَ هَذَا الْحَدِيثَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3941}\hadithtrans{Nafi, reported from Ibn Umar (Allah be pleated with them) that he came to Rafi and he narrated this hadith from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{3942}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا حُسَيْنٌ، - يَعْنِي ابْنَ حَسَنِ بْنِ يَسَارٍ - حَدَّثَنَا ابْنُ، عَوْنٍ عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَأْجُرُ الأَرْضَ - قَالَ - فَنُبِّئَ حَدِيثًا عَنْ رَافِعِ بْنِ خَدِيجٍ - قَالَ - فَانْطَلَقَ بِي مَعَهُ إِلَيْهِ - قَالَ - فَذَكَرَ عَنْ بَعْضِ عُمُومَتِهِ ذَكَرَ فِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ كِرَاءِ الأَرْضِ ‏.‏ قَالَ فَتَرَكَهُ ابْنُ عُمَرَ فَلَمْ يَأْجُرْهُ ‏.‏\hadithno{3942}\hadithtrans{Nafi, reported that Ibn Umar (Allah be pleased with them) used to rent the land, and that he was conveyed the hadith transmitted on the authority of Rafi b. Khadij. He (the narrator) said:He then went to him along with me. He (Rafi) narrated from some of his uncles in which it was mentioned that Allah's Apostle (ﷺ) forbade the renting of land. Ibn 'Umar (Allah be pleased with them) then abandoned this practice of renting}}
\hadithdefcmd{muslim}{3943}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا ابْنُ عَوْنٍ، بِهَذَا الإِسْنَادِ وَقَالَ فَحَدَّثَهُ عَنْ بَعْضِ، عُمُومَتِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3943}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{3944}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُكْرِي أَرَضِيهِ حَتَّى بَلَغَهُ أَنَّ رَافِعَ بْنَ خَدِيجٍ الأَنْصَارِيَّ كَانَ يَنْهَى عَنْ كِرَاءِ الأَرْضِ فَلَقِيَهُ عَبْدُ اللَّهِ فَقَالَ يَا ابْنَ خَدِيجٍ مَاذَا تُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي كِرَاءِ الأَرْضِ قَالَ رَافِعُ بْنُ خَدِيجٍ لِعَبْدِ اللَّهِ سَمِعْتُ عَمَّىَّ - وَكَانَا قَدْ شَهِدَا بَدْرًا - يُحَدِّثَانِ أَهْلَ الدَّارِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الأَرْضِ ‏.‏ قَالَ عَبْدُ اللَّهِ لَقَدْ كُنْتُ أَعْلَمُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ الأَرْضَ تُكْرَى ثُمَّ خَشِيَ عَبْدُ اللَّهِ أَنْ يَكُونَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْدَثَ فِي ذَلِكَ شَيْئًا لَمْ يَكُنْ عَلِمَهُ فَتَرَكَ كِرَاءَ الأَرْضِ ‏.‏\hadithno{3944}\hadithtrans{Salim b. Abdullah reported that AbduUah b. Umar (Allah be pleased with them) used to give land on rent until (this news) reached him that Rafi b. Khadij Ansari used to forbid the renting of land. Abdullah met him and said:Ibn Khadij, what is this that you narrate from Allah's Messenger (ﷺ) pertaining to renting of land? Rafi b. Khadij said to Abdullah: I heard it from two uncles of mine and they had participated in the Battle of Badr who narrated to the members of the family that Allah's Messenger (ﷺ) forbade the renting of land. Abdullah said: I knew it that the land was rented during the lifetime of Allah's Messenger (ﷺ). Abdullah then apprehended that Allah's Messenger (ﷺ) might have said something new in this connection (in regard to prohibition of renting) which I failed to know. So he abandoned the renting of land}}
\hadithdefcmd{muslim}{3945}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ أَيُّوبَ، عَنْ يَعْلَى بْنِ حَكِيمٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ كُنَّا نُحَاقِلُ الأَرْضَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنُكْرِيهَا بِالثُّلُثِ وَالرُّبُعِ وَالطَّعَامِ الْمُسَمَّى فَجَاءَنَا ذَاتَ يَوْمٍ رَجُلٌ مِنْ عُمُومَتِي فَقَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَمْرٍ كَانَ لَنَا نَافِعًا وَطَوَاعِيَةُ اللَّهِ وَرَسُولِهِ أَنْفَعُ لَنَا نَهَانَا أَنْ نُحَاقِلَ بِالأَرْضِ فَنُكْرِيَهَا عَلَى الثُّلُثِ وَالرُّبُعِ وَالطَّعَامِ الْمُسَمَّى وَأَمَرَ رَبَّ الأَرْضِ أَنْ يَزْرَعَهَا أَوْ يُزْرِعَهَا وَكَرِهَ كِرَاءَهَا وَمَا سِوَى ذَلِكَ ‏.‏\hadithno{3945}\hadithtrans{Rafi b. Khadij (Allah be pleased with him) reported:We used to give on rent land during the lifetime of Allah's Messenger (ﷺ). We rented it on the share of one-third or one-fourth of the (produce) along with a definite quantity of corn. One day a person from among my uncles came to us and said: Allah's Messenger (ﷺ) forbade us this act which was a source of benefit to us, but the obedience to Allah and to His Messenger (ﷺ) is more beneficial to us. He forbade us that we should rent land with one-third or one-fourth of (the produce) and the corn of a measure, and he commanded the owner of land that he should cultivate it or let it be cultivated by other (persons) but he showed disapproval of renting it or anything besides it}}
\hadithdefcmd{muslim}{3946}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، قَالَ كَتَبَ إِلَىَّ يَعْلَى بْنُ حَكِيمٍ قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، يُحَدِّثُ عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ كُنَّا نُحَاقِلُ بِالأَرْضِ فَنُكْرِيهَا عَلَى الثُّلُثِ وَالرُّبُعِ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ ابْنِ عُلَيَّةَ ‏.‏\hadithno{3946}\hadithtrans{Rafi b. Khadij (Allah be pleased with him) reported:We used to give land on rent, and we rented it on one-third or one-fourth share. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{3947}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الأَعْلَى، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدَةُ، كُلُّهُمْ عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ يَعْلَى بْنِ حَكِيمٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{3947}\hadithtrans{Another chain narrated the same as the above hadith}}
\hadithdefcmd{muslim}{3948}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ يَعْلَى بْنِ، حَكِيمٍ بِهَذَا الإِسْنَادِ عَنْ رَافِعِ بْنِ خَدِيجٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَقُلْ عَنْ بَعْضِ عُمُومَتِهِ ‏.‏\hadithno{3948}\hadithtrans{This hadith has been narrated on the authority of Rafi' b. Khadij with the same chain of transmitters, but in it no mention is made of some of his uncles}}
\hadithdefcmd{muslim}{3949}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو مُسْهِرٍ، حَدَّثَنِي يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي أَبُو عَمْرٍو الأَوْزَاعِيُّ، عَنْ أَبِي النَّجَاشِيِّ، مَوْلَى رَافِعِ بْنِ خَدِيجٍ عَنْ رَافِعٍ، أَنَّ ظُهَيْرَ بْنَ رَافِعٍ، - وَهُوَ عَمُّهُ - قَالَ أَتَانِي ظُهَيْرٌ فَقَالَ لَقَدْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَمْرٍ كَانَ بِنَا رَافِقًا ‏.‏ فَقُلْتُ وَمَا ذَاكَ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَهُوَ حَقٌّ ‏.‏ قَالَ سَأَلَنِي كَيْفَ تَصْنَعُونَ بِمَحَاقِلِكُمْ فَقُلْتُ نُؤَاجِرُهَا يَا رَسُولَ اللَّهِ عَلَى الرَّبِيعِ أَوِ الأَوْسُقِ مِنَ التَّمْرِ أَوِ الشَّعِيرِ ‏.‏ قَالَ ‏ "‏ فَلاَ تَفْعَلُوا ازْرَعُوهَا أَوْ أَزْرِعُوهَا أَوْ أَمْسِكُوهَا ‏"‏ ‏.‏\hadithno{3949}\hadithtrans{Rafi (Allah be pleased with him) reported that Zuhair b. Rafi (who was his uncle) came to me and said:Allah's Messenger (ﷺ) forbade a practice which was useful for us. I said: What is this? (I believe) that whatrver Allah's Messenger (ﷺ) says is absolutely true. He (Zuhair) said that he (the Holy Prophet) asked me: What do you do with your cultivable lands? I said: Allah's Messenger, we rent those irrigated by canals for dry dates or barley. He said: Don't do that. Cultivate them or let them be cultivated (by others) or retain them yourself}}
\hadithdefcmd{muslim}{3950}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ أَبِي النَّجَاشِيِّ، عَنْ رَافِعٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا وَلَمْ يَذْكُرْ عَنْ عَمِّهِ ظُهَيْرٍ\hadithno{3950}\hadithtrans{This hadith has been transmitted on the authority of Rafi from the Prophet (ﷺ) about this, but he did not make mention of his uncle Zuhair}}
\hadithdefcmd{muslim}{3951}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ، أَنَّهُ سَأَلَ رَافِعَ بْنَ خَدِيجٍ عَنْ كِرَاءِ الأَرْضِ، فَقَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كِرَاءِ الأَرْضِ قَالَ فَقُلْتُ أَبِالذَّهَبِ وَالْوَرِقِ فَقَالَ أَمَّا بِالذَّهَبِ وَالْوَرِقِ فَلاَ بَأْسَ بِهِ ‏.‏\hadithno{3951}\hadithtrans{Hanzala b. Qais reported that he asked Rafi b. Khadij (Allah be pleased with him) about renting of land, whereupon he said:Allah's Messenger (ﷺ) forbade the renting of land. I said: Is it forbidden (even if it is paid) in gold (dinar) and silver (dirham)? Thereupon he said: If it is paid in gold and silver, there is no harm in it}}
\hadithdefcmd{muslim}{3952}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ رَبِيعَةَ بْنِ أَبِي، عَبْدِ الرَّحْمَنِ حَدَّثَنِي حَنْظَلَةُ بْنُ قَيْسٍ الأَنْصَارِيُّ، قَالَ سَأَلْتُ رَافِعَ بْنَ خَدِيجٍ عَنْ كِرَاءِ الأَرْضِ، بِالذَّهَبِ وَالْوَرِقِ فَقَالَ لاَ بَأْسَ بِهِ إِنَّمَا كَانَ النَّاسُ يُؤَاجِرُونَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم عَلَى الْمَاذِيَانَاتِ وَأَقْبَالِ الْجَدَاوِلِ وَأَشْيَاءَ مِنَ الزَّرْعِ فَيَهْلِكُ هَذَا وَيَسْلَمُ هَذَا وَيَسْلَمُ هَذَا وَيَهْلِكُ هَذَا فَلَمْ يَكُنْ لِلنَّاسِ كِرَاءٌ إِلاَّ هَذَا فَلِذَلِكَ زُجِرَ عَنْهُ ‏.‏ فَأَمَّا شَىْءٌ مَعْلُومٌ مَضْمُونٌ فَلاَ بَأْسَ بِهِ ‏.‏\hadithno{3952}\hadithtrans{Hanzala b. Qais al-Ansri reported:I asked Rafi' b. Khadij about the renting of land for gold and silver, whereupon he said: There is no harm in it for the people let out land situated near canals and at the ends of the streamlets or portion of fields. (But it so happened) that at times this was destroyed and that was saved. whereas (on other occasions) this portion was saved and the other was destroyed and thus no rent was payable to the people (who let out lands) but for this one (which was saved). It was due to this that he (the Holy Prophet) prohibited it. But if there is something definite and reliable (e. g. money). there is no harm in it}}
\hadithdefcmd{muslim}{3953}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حَنْظَلَةَ، الزُّرَقِيِّ أَنَّهُ سَمِعَ رَافِعَ بْنَ خَدِيجٍ، يَقُولُ كُنَّا أَكْثَرَ الأَنْصَارِ حَقْلاً - قَالَ - كُنَّا نُكْرِي الأَرْضَ عَلَى أَنَّ لَنَا هَذِهِ وَلَهُمْ هَذِهِ فَرُبَّمَا أَخْرَجَتْ هَذِهِ وَلَمْ تُخْرِجْ هَذِهِ فَنَهَانَا عَنْ ذَلِكَ وَأَمَّا الْوَرِقُ فَلَمْ يَنْهَنَا ‏.‏\hadithno{3953}\hadithtrans{Hanzala reported that he heard Rafi' b. Khadij (Allah be pleased with him) say:We were the major agriculturists of the Ansar and so we let out land (saying): The produce of this (part of land) would be ours and (the produce) of that would be theirs. But it so happened that at times this (land) gave harvest, but the other one produced nothing. So he (the Holy Prophet) forbade this. But so far as the payment in silver (dirham, a coin) is concerned, he did not forbid}}
\hadithdefcmd{muslim}{3954}{حَدَّثَنَا أَبُو الرَّبِيعِ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، جَمِيعًا عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3954}\hadithtrans{This hadith has been narrated on the authority of Yahya b. Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{3955}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، كِلاَهُمَا عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ مَعْقِلٍ عَنِ الْمُزَارَعَةِ، فَقَالَ أَخْبَرَنِي ثَابِتُ بْنُ الضَّحَّاكِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَارَعَةِ ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبِي شَيْبَةَ نَهَى عَنْهَا ‏.‏ وَقَالَ سَأَلْتُ ابْنَ مَعْقِلٍ ‏.‏ وَلَمْ يُسَمِّ عَبْدَ اللَّهِ ‏.‏\hadithno{3955}\hadithtrans{Abdullah b. al Sa'ib reported:I asked Abdullah b. Ma'qil about Muzara'a (cultivating land on share basis in the produce). He said: Thabit b. Dahhak informed me that Allah's Messenger (ﷺ) forbade Muzara'a as Ibn Abu Shaiba forbade it with a slight change of words. He (the narrator) said: I asked Ibn Ma'qil but he did not name 'Abdullah}}
\hadithdefcmd{muslim}{3956}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَحْيَى بْنُ حَمَّادٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ سُلَيْمَانَ، الشَّيْبَانِيِّ عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ دَخَلْنَا عَلَى عَبْدِ اللَّهِ بْنِ مَعْقِلٍ فَسَأَلْنَاهُ عَنِ الْمُزَارَعَةِ، فَقَالَ زَعَمَ ثَابِتٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَارَعَةِ وَأَمَرَ بِالْمُؤَاجَرَةِ وَقَالَ ‏ "‏ لاَ بَأْسَ بِهَا ‏"‏ ‏.‏\hadithno{3956}\hadithtrans{Abdullah b. al-Sa'ib reported:We visited 'Abdullah b. Ma'qil and asked him about sharing of crops, whereupon he said: Thabit alleged that Allah's Messenger (ﷺ) forbade Muzara'a and commanded leasing it out on rent (for money) and said: There is no harm in it}}
\hadithdefcmd{muslim}{3957}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، أَنَّ مُجَاهِدًا، قَالَ لِطَاوُسٍ انْطَلِقْ بِنَا إِلَى ابْنِ رَافِعِ بْنِ خَدِيجٍ فَاسْمَعْ مِنْهُ الْحَدِيثَ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم - قَالَ - فَانْتَهَرَهُ قَالَ إِنِّي وَاللَّهِ لَوْ أَعْلَمُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهُ مَا فَعَلْتُهُ وَلَكِنْ حَدَّثَنِي مَنْ هُوَ أَعْلَمُ بِهِ مِنْهُمْ - يَعْنِي ابْنَ عَبَّاسٍ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ يَمْنَحَ الرَّجُلُ أَخَاهُ أَرْضَهُ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ عَلَيْهَا خَرْجًا مَعْلُومًا ‏"‏ ‏.‏\hadithno{3957}\hadithtrans{Mujahid said to Tiwus:Come along with me to Ibn Rafi b. Khadij in order to listen from him the hadith transmitted on the authority of his father (pertaining to the renting of land) from Allah's Apostle (ﷺ). He (Tawus) scolded him and said: By Allah, it I were to know that Allah's Messenger (ﷺ) had forbidden it, I would have never done it. But it has been narrated to me by one who has better knowledge of it amongst them (and he meant Ibn 'Abbas) that Allah's Messenger (ﷺ) said: It is better if a person lends, his land to his brother (for cultivation) than that he gets recognised rent on it}}
\hadithdefcmd{muslim}{3958}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، وَابْنُ، طَاوُسٍ عَنْ طَاوُسٍ، أَنَّهُ كَانَ يُخَابِرُ قَالَ عَمْرٌو فَقُلْتُ لَهُ يَا أَبَا عَبْدِ الرَّحْمَنِ لَوْ تَرَكْتَ هَذِهِ الْمُخَابَرَةَ فَإِنَّهُمْ يَزْعُمُونَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُخَابَرَةِ ‏.‏ فَقَالَ أَىْ عَمْرُو أَخْبَرَنِي أَعْلَمُهُمْ بِذَلِكَ يَعْنِي ابْنَ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَنْهَ عَنْهَا إِنَّمَا قَالَ ‏ "‏ يَمْنَحُ أَحَدُكُمْ أَخَاهُ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ عَلَيْهَا خَرْجًا مَعْلُومًا ‏"‏ ‏.‏\hadithno{3958}\hadithtrans{Tawus reported that he let out his land on rent, whereupon Amr said:I said to him: Abu Abd al-Rahrman, I wish if you abandon this renting of land, for they alleged that Allah's Apostle (ﷺ) forbade Mukhabara. He siad: Amr, one who has informed me has the best knowledge of it among them (he meant Ibn Abbas). (He said) that Allah's Apostle (ﷺ) did not prohibit it altogether, but said: Lending of land by one among you to his brother is better for him than getting a specified amount of produce from it}}
\hadithdefcmd{muslim}{3959}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا الثَّقَفِيُّ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ شَرِيكٍ، عَنْ شُعْبَةَ، كُلُّهُمْ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{3959}\hadithtrans{A hadith like this has been transmitted on the authority of Ibn Abbas (Allah be pleased with them)}}
\hadithdefcmd{muslim}{3960}{وَحَدَّثَنِي عَبْدُ بْنُ حُمَيْدٍ، وَمُحَمَّدُ بْنُ رَافِعٍ، - قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ يَمْنَحَ أَحَدُكُمْ أَخَاهُ أَرْضَهُ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ عَلَيْهَا كَذَا وَكَذَا ‏"‏ ‏.‏ لِشَىْءٍ مَعْلُومٍ ‏.‏ قَالَ وَقَالَ ابْنُ عَبَّاسٍ هُوَ الْحَقْلُ وَهُوَ بِلِسَانِ الأَنْصَارِ الْمُحَاقَلَةُ\hadithno{3960}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:If one among you lets out land to his brother, that is better for him than if he receives such and such (the definite thing). Ibn 'Abbis (Allah be pleased with them) said: It is Haql, and in the parlance of the Ansr it is Muhaqala}}
\hadithdefcmd{muslim}{3961}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ عَبْدِ الْمَلِكِ أَبِي زَيْدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ، عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَإِنَّهُ أَنْ يَمْنَحَهَا أَخَاهُ خَيْرٌ ‏"‏ ‏.‏\hadithno{3961}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:He who has land, it is better for him that he should let it out to his brother}}
